@@ -53,10 +53,12 @@ class Client:
     return response
 
   def overwrite(self, table_name, data, valueInputOption = "USER_ENTERED"):
+    fields = self.get(table_name).pop(0)
     oresponse = self.SHEET.values().clear(
       spreadsheetId=self.SHEET_ID, 
       range=f'{table_name}!A1:ZZZ',
       ).execute()
+    out_data = data.insert(0, fields)
     iresponse = self.insert(table_name, data, valueInputOption)
     return (oresponse, iresponse)
 
@@ -83,3 +85,17 @@ class Client:
     payload = [fields]
     for record in modified_data: payload.append([x for x in record.values()])
     return self.overwrite(table_name, payload)
+
+  def select(self, table_name, where_statement):
+    data = self.get(table_name)
+    fields = data.pop(0)
+    modified_data = []
+    for record in data: modified_data.append({fields[index]: item for index, item in enumerate(record)})
+    filtered, out_data = [], []
+    for record in modified_data:
+      if eval(where_statement): 
+        filtered.append(record)
+    for record in filtered: out_data.append([x for x in record.values()])
+    out_data.insert(0, fields)
+    return out_data
+    
\ No newline at end of file
